pub struct GraphicsMode<DI>where
DI: DisplayInterface,{ /* private fields */ }Expand description
Graphics mode handler
Implementations
Sourceimpl<DI> GraphicsMode<DI>where
DI: DisplayInterface,
impl<DI> GraphicsMode<DI>where
DI: DisplayInterface,
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear the display buffer. You need to call display.flush() for any effect on the screen
Sourcepub fn reset<RST, DELAY, PinE>(
&mut self,
rst: &mut RST,
delay: &mut DELAY,
) -> Result<(), Error<(), PinE>>
pub fn reset<RST, DELAY, PinE>( &mut self, rst: &mut RST, delay: &mut DELAY, ) -> Result<(), Error<(), PinE>>
Reset display
Sourcepub fn set_pixel(&mut self, x: u32, y: u32, value: u8)
pub fn set_pixel(&mut self, x: u32, y: u32, value: u8)
Turn a pixel on or off. A non-zero value is treated as on, 0 as off. If the X and Y
coordinates are out of the bounds of the display, this method call is a noop.
Sourcepub fn init(&mut self) -> Result<(), DI::Error>
pub fn init(&mut self) -> Result<(), DI::Error>
Display is set up in column mode, i.e. a byte walks down a column of 8 pixels from column 0 on the left, to column n on the right
Sourcepub fn get_dimensions(&self) -> (u8, u8)
pub fn get_dimensions(&self) -> (u8, u8)
Get display dimensions, taking into account the current rotation of the display
Sourcepub fn set_rotation(&mut self, rot: DisplayRotation) -> Result<(), DI::Error>
pub fn set_rotation(&mut self, rot: DisplayRotation) -> Result<(), DI::Error>
Set the display rotation